==> spread-5.1.0.48-py3-none-any.whl: spread-5.1.0.48.data/data/spread/dashboard/static/common/js/utils.js <==
log('common/utils.js loaded');
var loader = null;
var showLoaderTimer = null;
var hideLoaderTimer = null;

function guid() {
    function s4() {
        return Math.floor((1 + Math.random()) * 0x10000)
            .toString(16)
            .substring(1);
    }
    return s4() + s4() + '-' + s4() + '-' + s4() + '-' +
        s4() + '-' + s4() + s4() + s4();
}

function log(text) {
    const logDiv = $("#log")[0];
    if (logDiv) {
        logDiv.textContent += '\n' + text;
    }
}

function shake(element, callback) {
    element.classList.toggle('shake');
    window.setTimeout(function () {
            element.classList.toggle('shake');
            if (callback) callback();
        },
        300);
}

function showLoader() {
    loader = $('.content-blocker');
    if (loader.length > 0) {
        loader = loader[0];
        if (loader && showLoaderTimer === null) {
            if (hideLoaderTimer) {
                window.clearTimeout(hideLoaderTimer);
                hideLoaderTimer = null;
            }
            showLoaderTimer = window.setTimeout(function () {
                    loader.style.display = 'block';
                },
                100
            );
        }
    }
}

function hideLoader() {
    if (showLoaderTimer) {
        window.clearTimeout(showLoaderTimer);
        showLoaderTimer = null;
    }
    loader = $('.content-blocker');
    if (loader.length > 0) {
        loader = loader[0];
        hideLoaderTimer = window.setTimeout(function () {
            loader.style.display = 'none';
        }, 50);
    }
}

function init_client(broker, onConnect, onMessage) {
    const client = new Paho.MQTT.Client(document.location.hostname, broker.web_port, "webClient_" + guid());

    client.onConnectionLost = function (responseObject) {
        console.log("Connection Lost: "+responseObject.errorMessage);
    };
    client.onMessageArrived = function (message) {
        var data = message.payloadString;
        try { data = JSON.parse(message.payloadString); }
        catch (e) {}
        onMessage(message.destinationName, data);
    };

    client.connect(
        {
            userName: broker.login,
            password: broker.password,
            onSuccess: onConnect
        }
    );

    return client;
}

function request(url, onSuccess, onError, params, post) {
    if (url.substr(-1, 1) !== '/') url += '/';
    var data = {
        url: url,
    };
    if (params) {
        data.data = params;
    }

    log(url);

    showLoader();

    if (post) {
        $.post(data)
            .done(successHandler)
            .fail(errorHandler);
    }
    else {
        $.get(data)
            .done(successHandler)
            .fail(errorHandler);
    }

    function successHandler(data) {
        hideLoader();
        var result = null;
        try {
            result = JSON.parse(data);
        }
        catch (e) {
            log('SUCCESS');
            if (onSuccess) {
                onSuccess(data);
            }
            return;
        }

        if (result) {
            if (result.hasOwnProperty('error')) {
                log('ERROR');
                if (onError) {
                    onError(result, params);
                }
            } else {
                log('SUCCESS');
                if (onSuccess) {
                    onSuccess(result.result, params.data);
                }
            }
        }
    }

    function errorHandler(e) {
        hideLoader();
        log('FAILED');
        if (onError)
            onError(params);
    }
}

function hashCode(s) {
    return s;
}

==> spread-5.3.0.5-py3-none-any.whl: spread-5.3.0.5.data/data/spread/dashboard/static/common/js/utils.js <==
log('common/utils.js loaded');
var loader = null;
var showLoaderTimer = null;
var hideLoaderTimer = null;

function guid() {
    function s4() {
        return Math.floor((1 + Math.random()) * 0x10000)
            .toString(16)
            .substring(1);
    }
    return s4() + s4() + '-' + s4() + '-' + s4() + '-' +
        s4() + '-' + s4() + s4() + s4();
}

function log(text) {
    const logDiv = $("#log")[0];
    if (logDiv) {
        logDiv.textContent += '\n' + text;
    }
}

function shake(element, callback) {
    element.classList.toggle('shake');
    window.setTimeout(function () {
            element.classList.toggle('shake');
            if (callback) callback();
        },
        300);
}

function showLoader() {
    loader = $('.content-blocker');
    if (loader.length > 0) {
        loader = loader[0];
        if (loader && showLoaderTimer === null) {
            if (hideLoaderTimer) {
                window.clearTimeout(hideLoaderTimer);
                hideLoaderTimer = null;
            }
            showLoaderTimer = window.setTimeout(function () {
                    loader.style.display = 'block';
                },
                100
            );
        }
    }
}

function hideLoader() {
    if (showLoaderTimer) {
        window.clearTimeout(showLoaderTimer);
        showLoaderTimer = null;
    }
    loader = $('.content-blocker');
    if (loader.length > 0) {
        loader = loader[0];
        hideLoaderTimer = window.setTimeout(function () {
            loader.style.display = 'none';
        }, 50);
    }
}

function init_client(broker, onConnect, onMessage, onConnectionLost) {
    const client = new Paho.MQTT.Client(document.location.hostname, broker.web_port, "webClient_" + guid());

    client.onConnectionLost = function (responseObject) {
        console.log("Connection Lost: "+responseObject.errorMessage);
        onConnectionLost();
    };
    client.onMessageArrived = function (message) {
        var data = message.payloadString;
        try { data = JSON.parse(message.payloadString); }
        catch (e) {}
        onMessage(message.destinationName, data);
    };

    client.connect(
        {
            userName: broker.login,
            password: broker.password,
            onSuccess: onConnect
        }
    );

    return client;
}

function request(url, onSuccess, onError, params, post) {
    if (url.substr(-1, 1) !== '/') url += '/';
    var data = {
        url: url,
    };
    if (params) {
        data.data = params;
    }

    log(url);

    showLoader();

    if (post) {
        $.post(data)
            .done(successHandler)
            .fail(errorHandler);
    }
    else {
        $.get(data)
            .done(successHandler)
            .fail(errorHandler);
    }

    function successHandler(data) {
        hideLoader();
        var result = null;
        try {
            result = JSON.parse(data);
        }
        catch (e) {
            log('SUCCESS');
            if (onSuccess) {
                onSuccess(data);
            }
            return;
        }

        if (result) {
            if (result.hasOwnProperty('error')) {
                log('ERROR');
                if (onError) {
                    onError(result, params);
                }
            } else {
                log('SUCCESS');
                if (onSuccess) {
                    onSuccess(result.result, params.data);
                }
            }
        }
    }

    function errorHandler(e) {
        hideLoader();
        log('FAILED');
        if (onError)
            onError(params);
    }
}

function hashCode(s) {
    return s;
}
